######################################################################
# CUSTOMIZE YOUR BACKEND
#
# This file is auto-generated by Slush.
# 
# Purpose:
#   - You have to instantiate the Slush app here.
#   - You can define your routes here.
#   - If you want to have a seperate file or folder for routes, you can import `app` from this file.
#
# How to use:
#    - Each route function should return a response (JSON, string, etc.)
#    - Example routes are given below.
#
# Note:
#    - Feel free to completely customize the logic inside the routes.
#
######################################################################

# Example starter routes (you can delete or edit them)


from slush.app import Slush
from slush.core.response import Response
from slush.settings import Config

config = Config(debug=True)
app = Slush()

@app.route("/hello", methods=["GET"])
def hello(request):
    return Response(
        body={"message": "Hello World from Slush!"})